==> cherokee_0.4.13.orig.tar.gz: cherokee-0.4.13/src/log.c <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/* Cherokee
 *
 * Authors:
 *      Alvaro Lopez Ortega <alvaro@alobbs.com>
 *
 * Copyright (C) 2001, 2002, 2003, 2004 Alvaro Lopez Ortega
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */


#include "common.h"

#include <stdio.h>
#include <stdarg.h>
#include <syslog.h>
#include <stdlib.h>
#include <string.h>

#include "log.h"


static int __cherokee_logging = 0;

ret_t 
cherokee_log_init (void)
{
	openlog (PACKAGE, LOG_PID, LOG_DAEMON);
	__cherokee_logging = 1;
	return ret_ok;
}


ret_t 
cherokee_log_close (void)
{
	closelog();
	__cherokee_logging = 0;
	return ret_ok;
}


#ifndef HAVE_VSYSLOG
void 
vsyslog (int facility_priority, char *format, va_list arglist)
{
        char *msg = NULL;
        vasprintf(&msg, format, arglist);
        if (!msg)
                return;
        syslog(facility_priority, "%s", msg);
        free(msg);
}
#endif /* HAVE_VSYSLOG */


void inline
cherokee_log (int priority, const char *format, ...)
{	
	if (__cherokee_logging) {
		va_list l;

		va_start(l, format);
		vsyslog(priority, format, l);
		va_end(l);
	}
}

==> cherokee-0.4.17.1.tar.gz: cherokee-0.4.17/src/log.c <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/* Cherokee
 *
 * Authors:
 *      Alvaro Lopez Ortega <alvaro@alobbs.com>
 *
 * Copyright (C) 2001, 2002, 2003, 2004 Alvaro Lopez Ortega
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */


#include "common.h"

#include <stdio.h>
#include <stdarg.h>
#include <syslog.h>
#include <stdlib.h>
#include <string.h>

#include "log.h"


static int __cherokee_logging = 0;

ret_t 
cherokee_log_init (void)
{
	openlog (PACKAGE_NAME, LOG_PID, LOG_DAEMON);
	__cherokee_logging = 1;
	return ret_ok;
}


ret_t 
cherokee_log_close (void)
{
	closelog();
	__cherokee_logging = 0;
	return ret_ok;
}


#ifndef HAVE_VSYSLOG
void 
vsyslog (int facility_priority, char *format, va_list arglist)
{
        char *msg = NULL;
        vasprintf(&msg, format, arglist);
        if (!msg)
                return;
        syslog(facility_priority, "%s", msg);
        free(msg);
}
#endif /* HAVE_VSYSLOG */


void inline
cherokee_log (int priority, const char *format, ...)
{	
	if (__cherokee_logging) {
		va_list l;

		va_start(l, format);
		vsyslog(priority, format, l);
		va_end(l);
	}
}
